/* -*- mode: C++ ; c-basic-offset: 2; indent-tabs-mode: nil -*- */

%import "rovector.i"

%{

#include "nds_channel.hh"
#include "nds_str_helper.hh"

  struct chan_req_t;

  using NDS::channel;

%}

%define DOC_NDS_CHANNEL
"The channel class is used to describe an individual channel."
%enddef
%feature("autodoc", DOC_NDS_CHANNEL) channel;
class channel
{
public:
  %feature("autodoc","channel types") channel_type;
  %feature("autodoc","The channel type is unknown") CHANNEL_TYPE_UNKNOWN;
  typedef enum {
    CHANNEL_TYPE_UNKNOWN,
    CHANNEL_TYPE_ONLINE,
    CHANNEL_TYPE_RAW,
    CHANNEL_TYPE_RDS,
    CHANNEL_TYPE_STREND,
    CHANNEL_TYPE_MTREND,
    CHANNEL_TYPE_TEST_POINT,
    CHANNEL_TYPE_STATIC
  } channel_type;

  %feature("autodoc","data types") data_type;
  typedef enum {
    DATA_TYPE_UNKNOWN,
    DATA_TYPE_INT16,
    DATA_TYPE_INT32,
    DATA_TYPE_INT64,
    DATA_TYPE_FLOAT32,
    DATA_TYPE_FLOAT64,
    DATA_TYPE_COMPLEX32,
    DATA_TYPE_UINT32
  } data_type;
  
  typedef double sample_rate_type;
  typedef float signal_gain_type;
  typedef float signal_slope_type;
  typedef float signal_offset_type;
  typedef size_t      size_type;
  
  typedef std::vector< std::string > channel_names_type;

  static const channel_type DEFAULT_CHANNEL_MASK;
  static const data_type DEFAULT_DATA_MASK;

  static const sample_rate_type MIN_SAMPLE_RATE;
  static const sample_rate_type MAX_SAMPLE_RATE;

  %feature("autodoc", "Return the name of the channel") Name;
  const std::string& Name( ) const;

  std::string NameLong( );

  channel_type Type( ) const;

  data_type DataType( ) const;
  
  size_type DataTypeSize( ) const;

  sample_rate_type SampleRate( ) const;

  signal_gain_type Gain( ) const;

  signal_slope_type Slope( ) const;

  signal_offset_type Offset( ) const;

  const std::string& Units( ) const;

  // gwpy needs the channel_type_to_string
  %extend {
    static const std::string& channel_type_to_string(channel_type ctype)
    {
      return channel_type_to_string( ctype );
    }

    static const std::string& data_type_to_string(data_type dtype)
    {
      return data_type_to_string( dtype );
    }
  }

};

%template(channel_vector) std::vector< channel >;
%template(channel_rovector) rovector< channel >;
%template(channel_names_type) std::vector< std::string >;
